@@ -1,4 +1,4 @@
-"""Give users direct access to methods."""
+"""Gives users direct access to methods."""
 from b3u.b3u import\
     cred, credentials,\
     conf, configuration,\
